==> immersiveoverlays-1.4.1%2B1.21.8-fabric-sources.jar: cc/cassian/immersiveoverlays/compat/ColdSweatCompat.java <==
package cc.cassian.immersiveoverlays.compat;

import cc.cassian.immersiveoverlays.overlay.TemperatureOverlay;
import net.minecraft.class_2561;
import net.minecraft.class_746;

public class ColdSweatCompat {

    public static TemperatureOverlay.TemperaturePair getTemperaturePair(class_746 player) {
        long temperature = Math.round(getAmbientTemperature(player));
        double comparableTemperature;
        String sprite;
        int colour;
        if (isCelsius()) {
            comparableTemperature = (temperature * 1.8) + 32;
        } else {
            comparableTemperature = temperature;
        }
        if (comparableTemperature >= 121) {
            sprite = "heat_8";
            colour = 15545147;
        } else if (comparableTemperature > 115) {
            sprite = "heat_7";
            colour = 12539712;
        }  else if (comparableTemperature > 110) {
            sprite = "heat_6";
            colour = 16742400;
        }  else if (comparableTemperature > 100) {
            sprite = "heat_5";
            colour = 12545600;
        }  else if (comparableTemperature > 90) {
            sprite = "heat_4";
            colour = 16175917;
        }  else if (comparableTemperature > 78) {
            sprite = "heat_3";
            colour = 16311388;
        }  else if (comparableTemperature > 65) {
            sprite = "heat_2";
            colour = -1;
        }  else if (comparableTemperature > 30) {
            sprite = "heat_1";
            colour = 7906009;
        }  else {
            sprite = "heat_0";
            colour = 4169980;
        }
        return new TemperatureOverlay.TemperaturePair(class_2561.method_43470(String.valueOf(temperature)), colour, sprite);
    }

    public static double getAmbientTemperature(class_746 player) {
        //? if forge || neoforge {
        /*return Overlays.WORLD_TEMP;
        *///?} else {
        return 0;
        //?}
    }

    public static boolean isCelsius() {
        //? if forge || neoforge {
        /*return ConfigSettings.CELSIUS.get();
        *///?} else {
        return false;
         //?}
    }
}

==> immersiveoverlays-1.4.2%2B1.21.1-fabric-sources.jar: cc/cassian/immersiveoverlays/compat/ColdSweatCompat.java <==
package cc.cassian.immersiveoverlays.compat;

import cc.cassian.immersiveoverlays.helpers.TextHelpers;
import cc.cassian.immersiveoverlays.overlay.TemperatureOverlay;
import net.minecraft.class_746;

public class ColdSweatCompat {

    public static TemperatureOverlay.TemperaturePair getTemperaturePair(class_746 player) {
        long temperature = Math.round(getAmbientTemperature(player));
        double comparableTemperature;
        String sprite;
        int colour;
        if (isCelsius()) {
            comparableTemperature = (temperature * 1.8) + 32;
        } else {
            comparableTemperature = temperature;
        }
        if (comparableTemperature >= 121) {
            sprite = "heat_8";
            colour = 15545147;
        } else if (comparableTemperature > 115) {
            sprite = "heat_7";
            colour = 12539712;
        }  else if (comparableTemperature > 110) {
            sprite = "heat_6";
            colour = 16742400;
        }  else if (comparableTemperature > 100) {
            sprite = "heat_5";
            colour = 12545600;
        }  else if (comparableTemperature > 90) {
            sprite = "heat_4";
            colour = 16175917;
        }  else if (comparableTemperature > 78) {
            sprite = "heat_3";
            colour = 16311388;
        }  else if (comparableTemperature > 65) {
            sprite = "heat_2";
            colour = -1;
        }  else if (comparableTemperature > 30) {
            sprite = "heat_1";
            colour = 7906009;
        }  else {
            sprite = "heat_0";
            colour = 4169980;
        }
        return new TemperatureOverlay.TemperaturePair(TextHelpers.literal(String.valueOf(temperature)), colour, sprite);
    }

    public static double getAmbientTemperature(class_746 player) {
        //? if forge || neoforge {
        /*return Overlays.WORLD_TEMP;
        *///?} else {
        return 0;
        //?}
    }

    public static boolean isCelsius() {
        //? if forge || neoforge {
        /*return ConfigSettings.CELSIUS.get();
        *///?} else {
        return false;
         //?}
    }
}
